@@ -1,5 +1,5 @@
 from unittest import TestCase
-from random import choice
+from random import choice, random
 
 from tinydb_base import DatabaseBase
 from tinydb_base.output import exportToDict, exportToListOfDicts
@@ -9,6 +9,10 @@ class TestExport(TestCase):
 
     def testExportToDict(self):
         db = DatabaseBase('ds.test.json')
+
+        for thing in range(0, 500):
+            db.create({'title': '{}-{}'.format(thing, random())})
+
         randomRow = choice(db.readAll())
 
         obj = exportToDict(randomRow)
